pub struct Requirement { /* private fields */ }Expand description
A requirement is a document used to describe a system.
It can represent a user requirement, a specification, etc. Requirements can have dependencies between them, such that one requirement satisfies, fulfils, verifies (etc.) another requirement.
Implementations
Sourceimpl Requirement
impl Requirement
Sourcepub fn new(hrid: Hrid, content: String) -> Self
pub fn new(hrid: Hrid, content: String) -> Self
Construct a new Requirement from a human-readable ID and its content.
A new UUID is automatically generated.
The tags on the requirement
Set the tags on the requirement.
this replaces any existing tags.
Sourcepub fn add_tag(&mut self, tag: String) -> bool
pub fn add_tag(&mut self, tag: String) -> bool
Add a tag to the requirement.
returns ‘true’ if a new tag was inserted, or ‘false’ if it was already present.
Sourcepub const fn hrid(&self) -> &Hrid
pub const fn hrid(&self) -> &Hrid
The human-readable identifier for this requirement.
In normal usage these should be stable
Sourcepub fn fingerprint(&self) -> String
pub fn fingerprint(&self) -> String
Returns a value generated by hashing the content of the Requirement.
Any change to the requirement will change the fingerprint. This is used to determine when links are ‘suspect’. Meaning that because a requirement has been modified, related or dependent requirements also need to be reviewed to ensure consistency.
Sourcepub fn add_parent(
&mut self,
parent_id: Uuid,
parent_info: Parent,
) -> Option<Parent>
pub fn add_parent( &mut self, parent_id: Uuid, parent_info: Parent, ) -> Option<Parent>
Add a parent to the requirement, keyed by UUID.
Sourcepub fn parents(&self) -> impl Iterator<Item = (Uuid, &Parent)>
pub fn parents(&self) -> impl Iterator<Item = (Uuid, &Parent)>
Return an iterator over the requirement’s ‘parents’
Sourcepub fn parents_mut(&mut self) -> impl Iterator<Item = (Uuid, &mut Parent)>
pub fn parents_mut(&mut self) -> impl Iterator<Item = (Uuid, &mut Parent)>
Return a mutable iterator over the requirement’s ‘parents’
Sourcepub fn load(path: &Path, hrid: String) -> Result<Self, LoadError>
pub fn load(path: &Path, hrid: String) -> Result<Self, LoadError>
Reads a requirement from the given file path.
Note the path here is the path to the directory. The filename is determined by the HRID
Errors
Returns an error if the file does not exist, cannot be read from, or has malformed YAML frontmatter.
Sourcepub fn save(&self, path: &Path) -> Result<()>
pub fn save(&self, path: &Path) -> Result<()>
Writes the requirement to the given file path. Creates the file if it doesn’t exist, or overwrites it if it does.
Note the path here is the path to the directory. The filename is determined by the HRID.
Errors
This method returns an error if the path cannot be written to.